package main

import (
    "sync"
    "github.com/pkg/errors"
)

// configurationLock synchronizes access to the configuration.
var configurationLock sync.RWMutex

func (p *Plugin) OnConfigurationChange() error {
    var configuration = new(configuration)
    if err := p.API.LoadPluginConfiguration(configuration); err != nil {
        return errors.Wrap(err, "failed to load plugin configuration")
    }

    configurationLock.Lock()
    defer configurationLock.Unlock()
    p.configuration = configuration
    return nil
}

// getConfiguration safely retrieves the active configuration.
func (p *Plugin) getConfiguration() *configuration {
    configurationLock.RLock()
    defer configurationLock.RUnlock()
    return p.configuration
}